Documentation
¶
Overview ¶
Package goherokuname generates Heroku-like random names. Such as "black-block-0231".
It supports both decimal and hexadecimal suffixes. It supports customized rendering, in which the delimiter, the length of suffix and the acceptable characters for suffix are tweakable.
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Haikunate ¶
func Haikunate() string
Haikunate generate standard Heroku-like random name, with "-" as delimiter, decimal with 4 digits.
Example ¶
package main
import (
"fmt"
"cirello.io/goherokuname"
)
func main() {
fmt.Println(goherokuname.Haikunate())
}
Output: dawn-pond-0223
func HaikunateCustom ¶
HaikunateCustom generates a Heroku-like random name in which the delimiter, length and acceptable characters for suffix are tweakable.
Example ¶
package main
import (
"fmt"
"cirello.io/goherokuname"
)
func main() {
fmt.Println(goherokuname.HaikunateCustom("+", 5, "abcd"))
}
Output: tiny+limit+ddadc
func HaikunateHex ¶
func HaikunateHex() string
HaikunateHex generate standard Heroku-like random name, with "-" as delimiter, hexadecimal with 4 digits.
Example ¶
package main
import (
"fmt"
"cirello.io/goherokuname"
)
func main() {
fmt.Println(goherokuname.HaikunateHex())
}
Output: delicate-dawn-9869
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Comand herokuname runs the goherokuname package in CLI.
|
Comand herokuname runs the goherokuname package in CLI. |
Click to show internal directories.
Click to hide internal directories.